@@ -25,7 +25,7 @@ class StellarNet:  #Instantiated as SN
 #         Functions:
 #         TBD
 #
-#         '''
+#         '''po
 # =============================================================================
 # =============================================================================
 #     def __init__(self):
@@ -129,9 +129,9 @@ class StellarNet:  #Instantiated as SN
         plt.show()
 
 
-
-StellarNet = StellarNet()
+if __name__ == "__main__":
+    StellarNet = StellarNet()
 
 
-#%%  test bed
-StellarNet.Live()
+    #%%  test bed
+    StellarNet.Live()
